@@ -2,12 +2,18 @@
 #
 # Builds and tests CGNS for travis CI.
 #
+set -e
 cd src
 make
 make install
 cd tests
 make
 make test
+if [ $TRAVIS_OS_NAME = "linux" ]; then
+  cd ../ptests
+  make
+  make test
+fi
 cd ../examples/fortran
 make
 make test
